repytah — repytah 0.1.0dev documentation

# repytah

`repytah` is a Python package that builds aligned hierarchies, a representation for sequential data streams.

## Citing repytah

Please cite `repytah` using the following:

K. M. Kinnaird et al., repytah: A Python package that builds aligned hierarchies for sequential data streams. Python package version 0.1.0, 2021. [Online]. Available: https://github.com/smith-tinkerlab/repytah.

Getting Started

- Why repytah
- Installation

Modules

- Utilities
- Transform
- Assemble
- Search

Implementation

- Function Pipeline
- Example of Creating Aligned Hierarchies for a Mazurka Score

References

- Changelog
- Index